@@ -24,7 +24,6 @@
 
 #include <QGraphicsItem>
 #include <QPainter>
-#include <kdebug.h>
 
 #include "map.h"
 #include "mapitems.h"
@@ -43,13 +42,13 @@ MapScene::MapScene (Game *game)
     m_height(height())
 {
     m_renderer = new QSvgRenderer(IMAGES_SVG);
-    m_pixmapCache = new KPixmapCache("konquest-pixmaps");
+    m_imageCache = new KImageCache("konquest-pixmaps", 100000);
 }
 
 
 MapScene::~MapScene ()
 {
-    delete m_pixmapCache;
+    delete m_imageCache;
     delete m_renderer;
 }
 
@@ -68,7 +67,7 @@ void
 MapScene::selectPlanet(Planet *planet)
 {
     unselectPlanet();
-    foreach (PlanetItem *item, m_planetItems) {
+    for (PlanetItem *item : qAsConst(m_planetItems)) {
         if (item->sector() == planet->sector()) {
             item->select();
             m_selectedPlanetItem = item;
@@ -105,8 +104,7 @@ MapScene::mapUpdate()
                 sector = map()->sector(Coordinate(j, i));
                 if (sector->hasPlanet()) {
                     PlanetItem *item = new PlanetItem(this, sector, m_game);
-                    connect(item, SIGNAL(planetItemSelected (PlanetItem *)),
-                            this, SLOT(planetItemSelected (PlanetItem *)));
+                    connect(item, &PlanetItem::planetItemSelected, this, &MapScene::planetItemSelected);
                     item->setZValue(1.0);
                     addItem(item);
                     m_planetItems.append(item);
